<?php

namespace Drupal\block_style_plugins\Annotation;

use Drupal\Component\Annotation\Plugin;

/**
 * Defines a Block style item annotation object.
 *
 * @see \Drupal\block_style_plugins\Plugin\BlockStyleManager
 * @see plugin_api
 *
 * @Annotation
 */
class BlockStyle extends Plugin {

  /**
   * The plugin ID.
   *
   * @var string
   */
  public $id;

  /**
   * The label of the plugin.
   *
   * @var \Drupal\Core\Annotation\Translation
   *
   * @ingroup plugin_translatable
   */
  public $label;

  /**
   * The type of plugin this will support block, section, or all.
   *
   * @var string
   */
  public $type = 'block';

  /**
   * Block types to exclude.
   *
   * @var array
   */
  public $exclude = [];

  /**
   * Include only these block types.
   *
   * @var array
   */
  public $include = [];

  /**
   * Whether or not to embed the style form directly on the layout builder form.
   *
   * If set to true, the styles form will be embedded on the 'configure' form
   * of the layout builder block. Otherwise it will be added via a separate
   * 'Style settings' contextual link.
   *
   * @var boolean
   */
  public $layout_builder_embed_form = FALSE;

  /**
   * Do not automatically apply a css class based on the form value.
   *
   * @var boolean
   */
  public $disable_auto_classes = FALSE;

  /**
   * Restrict showing this plugin to only block_layout, layout_builder, or all.
   *
   * @var string
   */
  public $restrict_to;

  /**
   * The form Group label to put all fields in a plugin into a new fieldset.
   *
   * @var string
   */
  public $group;

}
