<?php

namespace Drupal\Tests\block_style_plugins\FunctionalJavascript;

use Drupal\layout_builder\Entity\LayoutBuilderEntityViewDisplay;
use Drupal\Tests\layout_builder\FunctionalJavascript\InlineBlockTestBase;

/**
 * Tests that the inline block feature works with styles.
 *
 * @group block_style_plugins
 */
class LayoutBuilderInlineBlockTest extends InlineBlockTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'node',
    'layout_builder',
    'block_style_plugins',
    'block_style_plugins_test',
    'contextual',
  ];

  /**
   * Default Theme.
   */
  protected $defaultTheme = 'starterkit_theme';

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->drupalLogin($this->drupalCreateUser([
      'configure any layout',
      'access contextual links',
      'create and edit custom blocks',
    ]));

    // Enable layout builder.
    LayoutBuilderEntityViewDisplay::load('node.bundle_with_section_field.default')
      ->enableLayoutBuilder()
      ->setOverridable()
      ->save();
  }

  /**
   * Tests that styles are correctly included/excluded from inline blocks.
   */
  public function testInlineBlocksVisibility() {
    $assert = $this->assertSession();

    $this->drupalGet('node/1/layout');

    // Add a basic block with the body field set.
    $this->addInlineBlockToLayout('Block title', 'The DEFAULT block body');

    // Force the finicky contextual links to be visible.
    $this->getSession()->executeScript("jQuery('" . static::INLINE_BLOCK_LOCATOR . " .contextual .trigger').each(function () {this.style.setProperty('position', 'relative', 'important')})");
    // Click the contextual link.
    $this->clickContextualLink(static::INLINE_BLOCK_LOCATOR, 'Style settings');
    $assert->assertWaitOnAjaxRequest();

    // There should not be an option for the excluded style.
    $assert->pageTextContains('Simple Class');
    $assert->pageTextContains('Dropdown with Include');
    $assert->pageTextNotContains('Checkbox with Exclude');
    $assert->pageTextNotContains('Styles Created by Yaml');
  }

}
